;;; conffile.el --- Major mode for a2ps' style of configuration files

;; Author: Akim Demaille (demaille@inf.enst.fr)
;; Maintainer: Akim Demaille (demaille@inf.enst.fr)
;; Keywords: languages, faces, a2ps

;;; Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
;;; Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana

;;;
;;; This file is part of a2ps.
;;; 
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
;;; any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; see the file COPYING.  If not, write to
;;; the Free Software Foundation, 59 Temple Place - Suite 330,
;;; Boston, MA 02111-1307, USA.
;;;

;; This file is (not yet) part of GNU Emacs.

;; $Id: conffile.el,v 1.1 2002/03/22 15:15:31 akim Exp $

;; to autoload a2ps lisp code:  
;; (autoload 'configfile-mode
;;   "configfile" "Mode for a2ps' style of configuration files" t)
;;
;; or can use (load "configfile-mode") or 
;;            (require 'configfile-mode) to just load it 
;;
;; to try to "auto-detect" configuration files:
;; (setq auto-mode-alist
;;     (cons '("\\(a2psrc\\|\\.edf\\)$" . configfile-mode) 
;; 	      auto-mode-alist))

(defvar configfile-font-lock-keywords
  `(
    ("^\\\#.*" . font-lock-comment-face)
    ("^\\([a-zA-Z]*:\\)" . font-lock-keyword-face)
    "default font-lock-keywords"))

;; this may still need some work
(defvar configfile-mode-syntax-table nil
  "syntax table used in configfile mode")
(setq configfile-mode-syntax-table (make-syntax-table))
(modify-syntax-entry ?\\  "_" configfile-mode-syntax-table)
(modify-syntax-entry ?@  "w" configfile-mode-syntax-table)
(modify-syntax-entry ?_  "w" configfile-mode-syntax-table)
(modify-syntax-entry ?*  "w" configfile-mode-syntax-table)

(defvar configfile-mode-map
  (let ((map (make-sparse-keymap)))
    (define-key map "\C-c\C-c" 'comment-region)
    map))

(defun configfile-mode ()
  "A major-mode to edit a2ps style sheet files
\\{configfile-mode-map}
"
  (interactive)
  (kill-all-local-variables)
  (use-local-map configfile-mode-map)

  (make-local-variable 'comment-start)
  (setq comment-start "#")
  (make-local-variable 'parse-sexp-ignore-comments)
  (setq parse-sexp-ignore-comments t)

  (make-local-variable	'font-lock-defaults)  
  (setq major-mode 'configfile-mode
	mode-name "configfile"
	font-lock-defaults `(configfile-font-lock-keywords nil))
  (set-syntax-table configfile-mode-syntax-table)
  (run-hooks 'configfile-mode-hook))

(provide 'configfile-mode)
;;; conffile.el ends here
